@@ -73,10 +73,11 @@ def bic_counter(data, arities, cols, weight=None):
     return bic
 
 
-def nal(data, cols, weight=None):
+def nal(data, cols, weight=None, alpha = 0.3):
     arities = np.amax(data, axis=0) + 1
     data_local = np.delete(data, data[:, cols].min(axis=1) < 0, axis=0)
-    alpha = 0.3 + data_local.shape[0] / data.shape[0] / 10
+    if alpha == 'auto':
+        alpha = 0.3 + data_local.shape[0] / data.shape[0] / 10
     if data_local.shape[0] == 0:
         return -np.inf
     else:
@@ -204,7 +205,7 @@ def density_counter(data, arities):
     return CT
 
 
-def local_score(data, cols, score_function='default', weights=None):
+def local_score(data, cols, score_function='default', weights=None, alpha=0.3):
     '''
     :param weights: weight for data
     :param data: numbered version of data set
@@ -218,7 +219,7 @@ def local_score(data, cols, score_function='default', weights=None):
         if score_function == 'default':
             score_function = 'bic' if 'int' in data.dtype.name else 'bic_g'
         try:
-            ls = globals()[score_function](data, np.asarray(cols), weights)
+            ls = globals()[score_function](data, np.asarray(cols), weights, alpha=alpha)
         except Exception as e:
             raise Exception('score function ' + str(
                 e) + ' is undefined or does not fit to data type. Available score functions are: bic (BIC for discrete variables) and nal (NAL for discrete variables).')
