@@ -64,7 +64,7 @@ def check_cycle(vi, vj, dag):
     return cyc_flag
 
 
-def hc(data, method='standard', score_function='default', debug=False):
+def hc(data, method='standard', score_function='default', debug=False, alpha=0.3):
     '''
         :param data: the training data used for learn BN
         :param method: the method for dealing with missing values, including:
@@ -302,7 +302,8 @@ def hc(data, method='standard', score_function='default', debug=False):
             raise Exception('Mixed data is not supported.')
         # initialise dag, cached scores and candidate parents for each variable
         dag = {var: {'par': [], 'nei': []} for var in varnames}
-        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score_function)} for var in varnames}
+        cache = {var: {tuple([]): local_score(data, [varnames.index(var)], score_function, alpha=alpha)} for var in
+                 varnames}
         candidate = {var: [v for v in varnames if v is not var] for var in varnames}
         time_preprocess = time.time() - start_time
         diff = 1
@@ -322,7 +323,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                         par_sea = tuple(sorted(dag[vj]['par'] + [vi]))
                         if par_sea not in cache[vj]:
                             cols = [varnames.index(x) for x in (vj,) + par_sea]
-                            cache[vj][par_sea] = local_score(data, cols, score_function)
+                            cache[vj][par_sea] = local_score(data, cols, score_function, alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[vj][par_sea] - cache[vj][tuple(dag[vj]['par'])]
                         if debug:
@@ -342,11 +343,11 @@ def hc(data, method='standard', score_function='default', debug=False):
                         par_sea_par_vi = tuple(sorted(dag[par_vi]['par'] + [vi]))
                         if par_sea_par_vi not in cache[par_vi]:
                             cols = [varnames.index(x) for x in (par_vi,) + par_sea_par_vi]
-                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function)
+                            cache[par_vi][par_sea_par_vi] = local_score(data, cols, score_function, alpha)
                         par_sea_vi = tuple([x for x in dag[vi]['par'] if x != par_vi])
                         if par_sea_vi not in cache[vi]:
                             cols = [varnames.index(x) for x in (vi,) + par_sea_vi]
-                            cache[vi][par_sea_vi] = local_score(data, cols, score_function)
+                            cache[vi][par_sea_vi] = local_score(data, cols, score_function, alpha)
                         time_score += time.time() - start_time
                         diff_temp = cache[par_vi][par_sea_par_vi] + cache[vi][par_sea_vi] - cache[par_vi][
                             tuple(dag[par_vi]['par'])] - cache[vi][tuple(dag[vi]['par'])]
@@ -362,7 +363,7 @@ def hc(data, method='standard', score_function='default', debug=False):
                     par_sea = tuple([x for x in dag[vi]['par'] if x != par_vi])
                     if par_sea not in cache[vi]:
                         cols = [varnames.index(x) for x in (vi,) + par_sea]
-                        cache[vi][par_sea] = local_score(data, cols, score_function)
+                        cache[vi][par_sea] = local_score(data, cols, score_function, alpha)
                     time_score += time.time() - start_time
                     diff_temp = cache[vi][par_sea] - cache[vi][tuple(dag[vi]['par'])]
                     if diff_temp - diff > 1e-10:
@@ -561,7 +562,7 @@ def pc_stable(data, test='default', threshold=0.05, debug=False):
 #     return post_process(dag, dc)
 
 
-def ges(data, method='complete', score_function='default', prune=True, thres=0.1, debug=False):
+def ges(data, method='complete', score_function='default', prune=True, thres=0.1, alpha=0.3, debug=False):
     '''
     greedy equivalence search algorithm
     :param data: the training data used for learn BN
@@ -633,11 +634,11 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
 
                             if parents_new not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache[y][parents_new] = local_score(data, cols, score_function)
+                                cache[y][parents_new] = local_score(data, cols, score_function, alpha)
                             score_new = cache[y][parents_new]
                             if parents_cur not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache[y][parents_cur] = local_score(data, cols, score_function)
+                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha)
                             score_cur = cache[y][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
@@ -680,11 +681,11 @@ def ges(data, method='complete', score_function='default', prune=True, thres=0.1
 
                             if parents_new not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_new]
-                                cache[y][parents_new] = local_score(data, cols, score_function)
+                                cache[y][parents_new] = local_score(data, cols, score_function, alpha)
                             score_new = cache[y][parents_new]
                             if parents_cur not in cache[y]:
                                 cols = [varnames.index(v) for v in (y,) + parents_cur]
-                                cache[y][parents_cur] = local_score(data, cols, score_function)
+                                cache[y][parents_cur] = local_score(data, cols, score_function, alpha)
                             score_cur = cache[y][parents_cur]
                             diff_temp = score_new - score_cur
                             if diff_temp > diff:
